@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Component/Core.pm 4230 2007-10-29T07:00:03.398091Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Component/Core.pm 8900 2007-11-10T15:40:32.116873Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -16,6 +16,7 @@ use HTTP::Status qw(status_message);
 use Gungho::Exception;
 use Gungho::Request;
 use Gungho::Response;
+use Gungho::Util;
 
 sub setup
 {
@@ -137,14 +138,11 @@ sub has_feature
 
 sub load_gungho_module
 {
-    my $c   = shift;
-    my $pkg    = shift;
-    my $prefix = shift;
-
-    unless ($pkg =~ s/^\+//) {
-        $pkg = ($prefix ? "Gungho::${prefix}::" : "Gungho::") . $pkg;
-    }
-
+    my ($c, $pkg, $prefix) = @_;
+    return Gungho::Util::load_module( 
+        $pkg,
+        $prefix ? "Gungho::${prefix}" : "Gunho"
+    );
     Class::Inspector->loaded($pkg) or $pkg->require or die;
     return $pkg;
 }
@@ -191,6 +189,12 @@ sub send_request
     $c->engine->send_request($c, $request);
 }
 
+sub pushback_request
+{
+    my ($c, $request) = @_;
+    $c->provider->pushback_request( $c, $request );
+}
+
 sub request_is_allowed { 1 }
 
 sub handle_response
@@ -340,6 +344,10 @@ Given a response, preps it before sending it to handle_response()
 
 Delegates to engine's send_request
 
+=head2 pushback_request
+
+Push back a request
+
 =head2 load_config($config)
 
 Loads the config from $config via Config::Any.
