@@ -1,4 +1,4 @@
-# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 4228 2007-10-29T06:56:31.308425Z lestrrat  $
+# $Id: /mirror/gungho/lib/Gungho/Engine/IO/Async.pm 8769 2007-11-08T05:55:36.931222Z lestrrat  $
 #
 # Copyright (c) 2007 Daisuke Maki <daisuke@endeworks.jp>
 # All rights reserved.
@@ -27,7 +27,9 @@ sub setup
     $self->setup_impl_class($c);
 
     $self->loop_delay( $self->config->{loop_delay} ) if $self->config->{loop_delay};
-
+    if (! $self->config->{dns}{disable}) {
+        $self->resolver(Net::DNS::Resolver->new);
+    }
 }
 
 sub setup_impl_class
@@ -52,7 +54,6 @@ sub setup_impl_class
 sub run
 {
     my ($self, $c) = @_;
-    $self->resolver(Net::DNS::Resolver->new);
     $self->impl->run($c);
 }
 
@@ -60,12 +61,12 @@ sub send_request
 {
     my ($self, $c, $request) = @_;
 
-    if ($request->requires_name_lookup) {
+    if ($self->resolver && $request->requires_name_lookup) {
         $self->lookup_host($c, $request);
     } else {
         $request->uri->host( $request->notes('resolved_ip') )
             if $request->notes('resolved_ip');
-        if ( $c->block_private_ip_address($request, $request->uri)) {
+        if ( ! $c->request_is_allowed($request)) {
             return;
         }
         $self->start_request($c, $request);
@@ -202,6 +203,16 @@ __END__
 
 Gungho::Engine::IO::Async - IO::Async Engine
 
+=head1 SYNOPSIS
+
+  engine:
+    module: IO::Async
+    config:
+        loop_delay: 0.01
+        dns:
+            disable: 1 # Only if you don't want Gungho to resolve DNS
+
+
 =head1 DESCRIPTION
 
 This class uses IO::Async to dispatch requests.
